@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
-from vcr import VCR                                                  
+from vcr import VCR
 
 __all__ = ['use_cassette']
 
@@ -8,7 +8,7 @@ def use_cassette(*args, **kwargs):
     return VCR(
         cassette_library_dir = os.path.join(os.path.dirname(__file__), 'cassettes', 'passaporte_web'),
         match_on = ['url', 'method', 'headers', 'body'],
-        record_mode = 'new_episodes',
+        record_mode = 'none',
     ).use_cassette(*args, **kwargs)
 
 
