@@ -4,7 +4,7 @@ import unittest
 import requests
 from .helpers import use_cassette as use_pw_cassette
 
-from passaporte_web.main import Application, Identity, Profile
+from passaporte_web.main import PassaporteWeb, Identity, Profile
 from passaporte_web.tests.helpers import TEST_USER, APP_CREDENTIALS
 
 __all__ = ['IdentityTest']
@@ -13,7 +13,7 @@ class IdentityTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
