@@ -5,7 +5,7 @@ import unittest
 import requests
 from .helpers import use_cassette as use_pw_cassette
 
-from passaporte_web.main import Application, AccountMembers, AccountMember
+from passaporte_web.main import PassaporteWeb, AccountMembers, AccountMember
 from passaporte_web.tests.helpers import TEST_USER, TEST_USER_2, APP_CREDENTIALS
 
 __all__ = ['AccountMembersTest', 'AccountMemberTest']
@@ -15,7 +15,7 @@ class AccountMembersTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
@@ -104,7 +104,7 @@ class AccountMemberTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
