@@ -6,7 +6,7 @@ import unittest
 import requests
 from .helpers import use_cassette as use_pw_cassette
 
-from passaporte_web.main import Application, Notification
+from passaporte_web.main import PassaporteWeb, Notification
 from passaporte_web.tests.helpers import TEST_USER, APP_CREDENTIALS
 
 __all__ = ['IdentityNotificationTest', 'ServiceAccountNotificationTest', 'NotificationTest']
@@ -16,7 +16,7 @@ class IdentityNotificationTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
@@ -60,7 +60,7 @@ class ServiceAccountNotificationTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
@@ -117,7 +117,7 @@ class NotificationTest(unittest.TestCase):
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
