@@ -6,7 +6,7 @@ import requests
 from api_toolkit import Collection
 from .helpers import use_cassette as use_pw_cassette
 
-from passaporte_web.main import Application, Identity, ServiceAccount, Account
+from passaporte_web.main import PassaporteWeb, Identity, ServiceAccount, Account
 from passaporte_web.tests.helpers import TEST_USER, APP_CREDENTIALS
 
 __all__ = ['IdentityAccountsTest']
@@ -327,7 +327,7 @@ class IdentityAccountsTest(CanGetServiceAccount, CanCreateServiceAccount, CanLoa
 
     def setUp(self):
         with use_pw_cassette('application/collections_options'):
-            self.app = Application(**APP_CREDENTIALS)
+            self.app = PassaporteWeb(**APP_CREDENTIALS)
 
         with use_pw_cassette('user/get_by_uuid'):
             self.user = self.app.users.get(uuid=TEST_USER['uuid'])
